# ABN Amro

This is an unofficial Python package that allows you to automatically obtain information about your bank accounts.

This can be useful if you want to automatically track your finances without relying on 3rd party applications.

### Installation
This package requires Python 3.10 or later and can be installed with pip: `pip install abnamro`. This package uses [semantic versioning](https://semver.org/).

### Documentation
* [The ABN AMRO API](https://github.com/kinnay/ABN-Amro/wiki)
* [The classes and functions in this package](https://abnamro.readthedocs.io)

### Example Scripts
* **mutations.py:** Requests your list of payment and savings accounts, and the 60 most recent mutations on the first account in the list.
